@@ -3,7 +3,7 @@ var webdeveloper_userStyleSheet = null;
 // Adds a user style sheet to the page
 function webdeveloper_addUserStyleSheet(element)
 {
-    var addStyleSheet = element.getAttribute("checked");
+    var addStyleSheet = webdeveloper_convertToBoolean(element.getAttribute("checked"));
 
     // If adding a style sheet
     if(addStyleSheet)
@@ -213,13 +213,13 @@ function webdeveloper_displayHandheldCSS(element)
     webdeveloper_configureElementByAppliedStyle(printElement, "checked", "webdeveloper-display-print-css");
 
     // If the print element is checked
-    if(printElement.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(printElement.getAttribute("checked")))
     {
         webdeveloper_displayCSSMediaType("print", true);
         webdeveloper_removeStyleSheet("webdeveloper-display-print-css");
     }
 
-    webdeveloper_displayCSSMediaType("handheld", !element.getAttribute("checked"));
+    webdeveloper_displayCSSMediaType("handheld", !webdeveloper_convertToBoolean(element.getAttribute("checked")));
     webdeveloper_toggleStyleSheet(element, "chrome://webdeveloper/content/stylesheets/empty.css", "webdeveloper-display-handheld-css");
 }
 
@@ -231,13 +231,13 @@ function webdeveloper_displayPrintCSS(element)
     webdeveloper_configureElementByAppliedStyle(handheldElement, "checked", "webdeveloper-display-handheld-css");
 
     // If the handheld element is checked
-    if(handheldElement.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(handheldElement.getAttribute("checked")))
     {
         webdeveloper_displayCSSMediaType("handheld", true);
         webdeveloper_removeStyleSheet("webdeveloper-display-handheld-css");
     }
 
-    webdeveloper_displayCSSMediaType("print", !element.getAttribute("checked"));
+    webdeveloper_displayCSSMediaType("print", !webdeveloper_convertToBoolean(element.getAttribute("checked")));
     webdeveloper_toggleStyleSheet(element, "chrome://webdeveloper/content/stylesheets/empty.css", "webdeveloper-display-print-css");
 }
 
@@ -306,7 +306,7 @@ function webdeveloper_toggleDocumentInlineStyles(node, disable)
 // Toggles all the embedded styles on the page
 function webdeveloper_toggleEmbeddedStyles(element)
 {
-    var disable          = element.getAttribute("checked");
+    var disable          = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList     = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength   = documentList.length;
     var pageDocument     = null;
@@ -341,7 +341,7 @@ function webdeveloper_toggleEmbeddedStyles(element)
 // Toggles all the inline styles in elements on the page
 function webdeveloper_toggleInlineStyles(element)
 {
-    var disable        = element.getAttribute("checked");
+    var disable        = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength = documentList.length;
 
@@ -357,7 +357,7 @@ function webdeveloper_toggleInlineStyles(element)
 // Toggles all the linked styles on the page
 function webdeveloper_toggleLinkedStyles(element)
 {
-    var disable          = element.getAttribute("checked");
+    var disable          = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList     = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength   = documentList.length;
     var ownerNode        = null;
@@ -392,7 +392,7 @@ function webdeveloper_toggleLinkedStyles(element)
 // Toggles the print styles for the page
 function webdeveloper_togglePrintStyles(element)
 {
-    var disable         = element.getAttribute("checked");
+    var disable         = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList    = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength  = documentList.length;
     var pageDocument    = null;
@@ -441,7 +441,7 @@ function webdeveloper_toggleStyles(element)
     // If the element is set
     if(element)
     {
-        disable = element.getAttribute("checked");
+        disable = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     }
     else
     {
@@ -473,7 +473,7 @@ function webdeveloper_toggleStyles(element)
             // If this is a valid style sheet and is not an alternate style sheet
             if(webdeveloper_isValidStyleSheet(styleSheet) && (!webdeveloper_isAlternateStyleSheet(styleSheet) || disable))
             {
-                styleSheet.disabled = disable;
+				styleSheet.disabled = disable;
             }
         }
 
