@@ -93,7 +93,7 @@ function webdeveloper_displayElementInformation(element)
     // If the element is set
     if(element)
     {
-        checked = element.getAttribute("checked");
+        checked = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     }
     else
     {
@@ -136,7 +136,7 @@ function webdeveloper_displayElementInformation(element)
             }
 
             pageDocument.addEventListener("click", webdeveloper_displayElementInformationForElement, true);
-            pageDocument.addEventListener("keypress", webdeveloper_displayElementInformationKeyPress, false);
+            //pageDocument.addEventListener("keypress", webdeveloper_displayElementInformationKeyPress, false);
             pageDocument.addEventListener("mousemove", webdeveloper_displayElementInformationMouseMove, false);
             pageDocument.addEventListener("mouseover", webdeveloper_displayElementInformationMouseOver, false);
         }
@@ -154,6 +154,7 @@ function webdeveloper_displayElementInformation(element)
                 // Do nothing
             }
 
+			/*
             // Try to remove the event listener
             try
             {
@@ -163,6 +164,7 @@ function webdeveloper_displayElementInformation(element)
             {
                 // Do nothing
             }
+			*/
 
             // Try to remove the event listener
             try
