@@ -1,7 +1,7 @@
 // Displays all alt attributes
 function webdeveloper_displayAltAttributes(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var imageElement        = null;
@@ -52,7 +52,7 @@ function webdeveloper_displayAltAttributes(element)
 // Displays all image dimensions
 function webdeveloper_displayImageDimensions(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var dimensions          = null;
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
@@ -127,7 +127,7 @@ function webdeveloper_displayImageDimensions(element)
 // Displays all image file sizes
 function webdeveloper_displayImageFileSizes(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var fileSize            = null;
@@ -182,7 +182,7 @@ function webdeveloper_displayImageFileSizes(element)
 // Displays all image paths
 function webdeveloper_displayImagePaths(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var imageElement        = null;
@@ -357,7 +357,7 @@ function webdeveloper_hideImages(element, id)
 {
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
-    var hide                = element.getAttribute("checked");
+    var hide                = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var inputElement        = null;
     var inputElementList    = null;
     var inputElementsLength = null;
@@ -447,7 +447,7 @@ function webdeveloper_makeImagesInvisible(element, id)
     var inputElement        = null;
     var inputElementList    = null;
     var inputElementsLength = null;
-    var invisible           = element.getAttribute("checked");
+    var invisible           = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var pageDocument        = null;
 
     // Loop through the documents
@@ -527,7 +527,7 @@ function webdeveloper_outlineAllImages(element)
 function webdeveloper_outlineBackgroundImages(element, toggleStyleSheet)
 {
     var backgroundImage = null;
-    var checked         = element.getAttribute("checked");
+    var checked         = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var cssURI          = CSSPrimitiveValue.CSS_URI;
     var documentList    = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength  = documentList.length;
@@ -580,7 +580,7 @@ function webdeveloper_outlineBackgroundImages(element, toggleStyleSheet)
 // Outlines all the images with adjusted dimensions
 function webdeveloper_outlineImagesWithAdjustedDimensions(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var imageElement        = null;
@@ -627,7 +627,7 @@ function webdeveloper_outlineImagesWithAdjustedDimensions(element)
 // Outlines all the images with oversized dimensions
 function webdeveloper_outlineImagesWithOversizedDimensions(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var imageElement        = null;
@@ -699,7 +699,7 @@ function webdeveloper_outlineImagesWithoutTitleAttributes(element)
 function webdeveloper_replaceImagesWithAltAttributes(element)
 {
     var altAttribute        = null;
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var imageElement        = null;
@@ -751,7 +751,7 @@ function webdeveloper_toggleExternalSiteImages(element)
     var legacyImageBehavior = 0;
 
     // If disabling external images
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         imageBehavior       = 3;
         legacyImageBehavior = 1;
@@ -768,7 +768,7 @@ function webdeveloper_toggleImageAnimations(element)
     var imageBehavior = "normal";
 
     // If disabling images
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         imageBehavior = "none";
     }
@@ -784,7 +784,7 @@ function webdeveloper_toggleImages(element)
     var legacyImageBehavior = 0;
 
     // If disabling images
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         imageBehavior       = 2;
         legacyImageBehavior = 2;
