@@ -30,7 +30,7 @@ function webdeveloper_displayAccessKeys(element)
     var accessKeyElement        = null;
     var accessKeyElementList    = null;
     var accessKeyElementsLength = null;
-    var display                 = element.getAttribute("checked");
+    var display                 = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList            = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength          = documentList.length;
     var pageDocument            = null;
@@ -76,12 +76,14 @@ function webdeveloper_displayAnchors(element)
     var anchorElement        = null;
     var anchorElementList    = null;
     var anchorElementsLength = null;
+    var anchorLocation       = null;
     var anchorText           = null;
-    var display              = element.getAttribute("checked");
+    var display              = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList         = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength       = documentList.length;
     var linkElement          = null;
     var pageDocument         = null;
+    var pageLocation         = null;
     var spanElement          = null;
 
     // Loop through the documents
@@ -97,6 +99,8 @@ function webdeveloper_displayAnchors(element)
         {
             anchorElementList    = webdeveloper_evaluateXPath(pageDocument, "//*[@id] | //a[@name]");
             anchorElementsLength = anchorElementList.length;
+	        pageLocation         = pageDocument.location;
+	        anchorLocation       = pageLocation.pathname + pageLocation.search;
 
             // Loop through all the anchor elements
             for(var j = 0; j < anchorElementsLength; j++)
@@ -115,7 +119,7 @@ function webdeveloper_displayAnchors(element)
                     anchorText = "#" + anchorElement.getAttribute("name");
                 }
 
-                linkElement.setAttribute("href", anchorText);
+                linkElement.setAttribute("href", anchorLocation + anchorText);
                 linkElement.setAttribute("title", anchorText);
                 linkElement.appendChild(pageDocument.createTextNode(anchorText));
 
@@ -147,7 +151,7 @@ function webdeveloper_displayBlockSize(element)
     var blockSizeElement        = null;
     var blockSizeElementList    = null;
     var blockSizeElementsLength = null;
-    var display                 = element.getAttribute("checked");
+    var display                 = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList            = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength          = documentList.length;
     var height                  = null;
@@ -203,7 +207,7 @@ function webdeveloper_displayBlockSize(element)
 // Displays the order of the divs on the page
 function webdeveloper_displayDivOrder(element)
 {
-    var display            = element.getAttribute("checked");
+    var display            = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var divElement         = null;
     var divElementList     = null;
     var divElementsLength  = null;
@@ -250,7 +254,7 @@ function webdeveloper_displayDivOrder(element)
 // Displays id and class details for the page
 function webdeveloper_displayIdClassDetails(element)
 {
-    var display               = element.getAttribute("checked");
+    var display               = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList          = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength        = documentList.length;
     var idClassElement        = null;
@@ -329,7 +333,7 @@ function webdeveloper_displayLinkDetails(element)
 // Displays object information
 function webdeveloper_displayObjectInformation(element)
 {
-    var checked              = element.getAttribute("checked");
+    var checked              = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var divElement           = null;
     var documentList         = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength       = documentList.length;
@@ -467,7 +471,7 @@ function webdeveloper_displayObjectInformation(element)
 // Displays the stack level of all elements on the page
 function webdeveloper_displayStackLevels(element)
 {
-    var display            = element.getAttribute("checked");
+    var display            = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList       = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength     = documentList.length;
     var pageDocument       = null;
@@ -511,7 +515,7 @@ function webdeveloper_displayStackLevels(element)
 // Displays all tab indices
 function webdeveloper_displayTabIndex(element)
 {
-    var checked                = element.getAttribute("checked");
+    var checked                = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList           = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength         = documentList.length;
     var pageDocument           = null;
@@ -557,7 +561,7 @@ function webdeveloper_displayTabIndex(element)
 // Displays the depth of all tables
 function webdeveloper_displayTableDepth(element)
 {
-    var checked             = element.getAttribute("checked");
+    var checked             = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList        = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength      = documentList.length;
     var pageDocument        = null;
@@ -604,7 +608,7 @@ function webdeveloper_displayTableDepth(element)
 // Displays table information
 function webdeveloper_displayTableInformation(element)
 {
-    var checked                 = element.getAttribute("checked");
+    var checked                 = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var divElement              = null;
     var documentList            = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength          = documentList.length;
@@ -671,7 +675,7 @@ function webdeveloper_displayTableInformation(element)
 // Displays all title attributes
 function webdeveloper_displayTitleAttributes(element)
 {
-    var checked                      = element.getAttribute("checked");
+    var checked                      = webdeveloper_convertToBoolean(element.getAttribute("checked"));
     var documentList                 = webdeveloper_getDocuments(webdeveloper_getContentWindow());
     var documentLength               = documentList.length;
     var pageDocument                 = null;
@@ -1730,6 +1734,8 @@ function webdeveloper_viewDocumentOutline()
     var documentURL          = null;
     var headerElementList    = null;
     var headerElementsLength = null;
+    var headerImageList      = null;
+    var headerImagesLength   = null;
     var headerLevel          = null;
     var headerTagName        = null;
     var headerText           = null;
@@ -1804,7 +1810,27 @@ function webdeveloper_viewDocumentOutline()
             // If there is no header text
             if(!headerText)
             {
-                headerText = stringBundle.getString("webdeveloper_viewDocumentOutlineEmptyHeading");
+            	headerImageList    = webdeveloper_evaluateXPath(headerElement, "img[@alt]");
+            	headerImagesLength = headerImageList.length;
+            	headerText         = "";
+ 
+				// Loop through the heading images
+				for(var k = 0; k < headerImagesLength; k++)
+				{
+					headerText += headerImageList[k].getAttribute("alt") + " ";
+				}
+           
+           		headerText = headerText.trim();
+           
+				// If there is now header text
+				if(headerText)
+				{
+					headerText = "[" + headerText + "]";
+				}
+				else
+				{
+					headerText = stringBundle.getString("webdeveloper_viewDocumentOutlineEmptyHeading");
+				}
             }
 
             outlineElement = generatedDocument.createElement(headerTagName);
