@@ -42,8 +42,8 @@ function webdeveloper_addElementOutline(event, currentElement)
 {
     var element = event.target;
 
-    // If the element is set and is not the same as the current outline element
-    if(element && element != currentElement)
+    // If the element is set, is not the same as the current outline element and has a style property
+    if(element && element != currentElement && element.style)
     {
         webdeveloper_removeElementOutline(currentElement);
 
@@ -71,6 +71,8 @@ function webdeveloper_addGeneratedStyles(generatedDocument)
     styleElement.setAttribute("type", "text/css");
     styleElement.appendChild(generatedDocument.createTextNode("body, td, th { font-size: " + webdeveloper_getIntegerPreference("webdeveloper.generated.content.font.size", true) + "px !important; }"));
     headElement.appendChild(styleElement);
+    
+    generatedDocument.documentElement.setAttribute("id", "webdeveloper-generated-content");
 }
 
 // Adds the generated tools to a page
@@ -829,7 +831,7 @@ function webdeveloper_disablePreference(element, preference)
     // If the element and preference are set
     if(element && preference)
     {
-        webdeveloper_setBooleanPreference(preference, !element.getAttribute("checked"));
+        webdeveloper_setBooleanPreference(preference, !webdeveloper_convertToBoolean(element.getAttribute("checked")));
     }
 }
 
@@ -872,6 +874,8 @@ function webdeveloper_enablePreference(element, preference)
     // If the element and preference are set
     if(element && preference)
     {
+    	webdeveloper_setBooleanPreference(preference, webdeveloper_convertToBoolean(element.getAttribute("checked")));
+/*
         var checked = element.getAttribute("checked");
 
         // If the element is checked (explicit check required)
@@ -883,6 +887,7 @@ function webdeveloper_enablePreference(element, preference)
         {
             webdeveloper_setBooleanPreference(preference, false);
         }
+*/
     }
 }
 
@@ -1033,6 +1038,18 @@ function webdeveloper_isDOMInspectorAvailable()
     }
 }
 
+// Returns true if the DOM Inspector chrome is available
+function webdeveloper_isDOMInspectorChromeAvailable()
+{
+	// If the inspectDOMDocument method is available
+	if(typeof inspectDOMDocument == "function")
+	{
+		return true;
+	}
+	
+	return false;
+}
+
 // Returns true if the information text toolbar is in use
 function webdeveloper_isInformationTextToolbarInUse()
 {
@@ -1579,7 +1596,7 @@ function webdeveloper_toggleAppliedStyle(element, id)
     webdeveloper_removeAppliedStyle(id);
 
     // If the menu is checked
-    if(element && element.getAttribute("checked"))
+    if(element && webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         webdeveloper_addAppliedStyle(id);
     }
@@ -1591,7 +1608,7 @@ function webdeveloper_toggleFeatureTooltipStyles(element, styleSheetId, selector
     webdeveloper_removeStyleSheet(styleSheetId, false);
 
     // If the menu is checked
-    if(element.getAttribute("checked"))
+    if(webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         var colors         = " background-color: " + webdeveloper_getStringPreference("webdeveloper.feature.tooltip.color.background", true) + " !important; border-color: " + webdeveloper_getStringPreference("webdeveloper.feature.tooltip.color.border", true) + " !important; color: " + webdeveloper_getStringPreference("webdeveloper.feature.tooltip.color.text", true) + " !important; ";
         var documentList   = webdeveloper_getDocuments(webdeveloper_getContentWindow());
@@ -1645,7 +1662,7 @@ function webdeveloper_toggleStyleSheet(element, location, id)
     webdeveloper_removeStyleSheet(id);
 
     // If the menu is checked
-    if(element && element.getAttribute("checked"))
+    if(element && webdeveloper_convertToBoolean(element.getAttribute("checked")))
     {
         webdeveloper_addStyleSheet(location, id);
     }
